=========
Changelog
=========

Version 1.0.0
=============

- Stable Version.
- Support C & C++.

Version 0.3.0
=============

- Cleanup stale arguments.

Version 0.2.8
=============

- Fix go, rust and java runtimes.

Version 0.2.7
=============

- Support custom OCI runtimes for better isolation between the application and the host kernel.

Version 0.2.6
=============

- Support isolated containers

Version 0.2.4
=============

- Fixes.

Version 0.2.3
=============

- Fixes.

Version 0.2.2
=============

- Fixes.

Version 0.2.1
=============

- Fixes.

Version 0.1.0
=============

- Initial Release.
